==> atlassian_connect_host-0.3.5.tar.gz: lib/host_event_model.dart <==
library ac_dart.host_event_model;

import 'package:atlassian_connect_host/host_model.dart';
export 'package:atlassian_connect_host/host_model.dart';

import 'package:constrain/constrain.dart';

class AcHostEventType {
  final int ordinal;
  final String literal;
  const AcHostEventType(this.ordinal, this.literal);

  static const AcHostEventType installed = const AcHostEventType(1, 'installed');
  static final Map<String, AcHostEventType> _eventTypes = { 
      installed.literal: installed
  };

  static AcHostEventType fromLiteral(String literal) => _eventTypes[literal];
  
  String toString() => literal;
}

abstract class AcHostEvent {
  @NotNull()
  final AcHostEventType eventType;

  AcHostEvent(this.eventType);
  
  Map toJson() => {
    'eventType': eventType.toString()
  };

}

class InstallationEvent extends AcHostEvent {
  @NotNull()
  final AcHostRegistration hostRegistration;

  InstallationEvent(AcHostEventType eventType, this.hostRegistration)
      : super(eventType);

  InstallationEvent.fromJson(Map<String, Object> jsonMap)
      : this(AcHostEventType.installed, (new MutableAcHostRegistration()
          ..sharedSecret = jsonMap['sharedSecret']
          ..hostDetails = (new MutableAcHostDetails()
              ..key = jsonMap['clientKey']
              ..baseUrl = Uri.parse(jsonMap['baseUrl'])
              ..productType = ProductType.fromLiteral(jsonMap['productType'])
              ..publicKey = jsonMap['publicKey'])).toImmutable());

  Map toJson() => super.toJson()..addAll({
    'hostRegistration': hostRegistration
  });
  
  String toString() => 'InstallationEvent[$hostRegistration]';
}

==> atlassian_connect_host-0.4.0.tar.gz: lib/host_event_model.dart <==
library ac_dart.host_event_model;

import 'package:atlassian_connect_host/host_model.dart';
export 'package:atlassian_connect_host/host_model.dart';

import 'package:constrain/constrain.dart';

class AcHostEventType {
  final int ordinal;
  final String literal;
  const AcHostEventType(this.ordinal, this.literal);

  static const AcHostEventType installed = const AcHostEventType(1, 'installed');
  static final Map<String, AcHostEventType> _eventTypes = { 
      installed.literal: installed
  };

  static AcHostEventType fromLiteral(String literal) => _eventTypes[literal];
  
  String toString() => literal;
}

abstract class AcHostEvent {
  @NotNull()
  final AcHostEventType eventType;

  AcHostEvent(this.eventType);
  
  Map toJson() => {
    'eventType': eventType.toString()
  };

}

class InstallationEvent extends AcHostEvent {
  @NotNull()
  final AcHostRegistration hostRegistration;

  InstallationEvent(this.hostRegistration)
      : super(AcHostEventType.installed);

  InstallationEvent.fromJson(Map<String, Object> jsonMap)
      : this((new AcHostRegistration.build(
          sharedSecret: jsonMap['sharedSecret'],
          hostDetails: (new AcHostDetails.build(
              key: jsonMap['clientKey'],
              baseUrl: Uri.parse(jsonMap['baseUrl']),
              productType: productTypeFromLiteral(jsonMap['productType']),
              publicKey: jsonMap['publicKey'])))));

  Map toJson() => super.toJson()..addAll({
    'hostRegistration': hostRegistration
  });
  
  String toString() => 'InstallationEvent[$hostRegistration]';
}
